#SingleInstance Force
full_command_line := DllCall("GetCommandLine", "str")
if not (A_IsAdmin or RegExMatch(full_command_line, " /restart(?!\S)"))
{
  try
  {
    if A_IsCompiled
      Run '*RunAs "' A_ScriptFullPath '" /restart'
    else
      Run '*RunAs "' A_AhkPath '" /restart "' A_ScriptFullPath '"'
  }
  ExitApp
}

#CommentFlag // ClipSeriesPlayer v2.0 by Carm3D Feb 20, 2024

#CommentFlag // If you are wearing a motion capture suit and want to tell your computer
#CommentFlag // to play an audio clip (or a series of them) without having to touch
#CommentFlag // your mouse, this is the AutoHotKey script for you!

#CommentFlag // This works great with VoiceAttack, use one of the (command line)
#CommentFlag // parameters to choose how the script functions:

#CommentFlag // ResetScript = Makes the current clip 1
#CommentFlag // PlayCurrentClip = Plays the current clip
#CommentFlag // PlayNextClip = Adds 1 to current clip value then plays it
#CommentFlag // PlayPreviousClip = Subtracts 1 from current clip value then plays it

#CommentFlag // Use "Reset Script" first to create a variable value
#CommentFlag // If you start with "Play Current Clip" it will create the variable file
#CommentFlag // but will not play it.  Use "Play Current Clip" again to then play it.

#CommentFlag // Set SoundPath to the location of your series of audip clips
#CommentFlag // It assumes your clips are named Clip_01.wav, Clip_02.wav, Clip_03.wav
#CommentFlag // through Clip_99.wav

#CommentFlag // ScriptPath is where you want it to write it's text-based variable
#CommentFlag // for keeping track of where it is in your script.  A good location is
#CommentFlag // where you put this .AHK script file.

#CommentFlag // Note I am using #Persistent to keep the script running while it plays
#CommentFlag // the audio (and forevermore until it is launched again or your reboot)
#CommentFlag // A more efficient method would be to tell an external program to play your
#CommentFlag // clips such as VLC

#SingleInstance Force

CommandVar = %1%
global ScriptValue
global ScriptCount

#CommentFlag //
#CommentFlag // Edit these as needed / desired.
#CommentFlag // UseVLC 1 = play with VLC
#CommentFlag // UseVLC 0 = play with internal SoundPlay command
#CommentFlag //

global SoundPath := "P:\Tutorial_ClipSeriesPlayer"
global ScriptPath := "F:\Text\AutoHotKey\ClipSeriesPlayer\"
global DisplayText := 1
global PlayBeeps := 1
global UseVLC := 0
		
#CommentFlag //
#CommentFlag //
#CommentFlag //

#CommentFlag // Read and update script count
ReadScriptCount()
If (CommandVar = "PlayPreviousClip"){
	ScriptCount := ScriptCount - 1
	if (ScriptCount < 1) {
		ScriptCount := 1
		}
	#CommentFlag // ComObjCreate("SAPI.SpVoice").Speak(ScriptCount)
	WriteScript()
	}
If (CommandVar = "PlayNextClip"){
	ScriptCount := ScriptCount + 1
	#CommentFlag // ComObjCreate("SAPI.SpVoice").Speak(ScriptCount)
	WriteScript()
	}		

if (DisplayText = 1){
	Gui, -Caption +AlwaysOnTop +Owner +LastFound 
	WinSet, TransColor, EEAA99
	Gui, Color, EEAA99
	Gui, Font, s80 w700 q4, Times New Roman
	if (CommandVar = "ResetScript"){
		Gui, Add, Text,, Reset Script
		}
	if (CommandVar != "ResetScript"){
		Gui, Add, Text,, Playing Clip %ScriptCount%
		}

	Gui, Show
}


if (CommandVar = "ResetScript"){
	ResetScript()
	}

if (PlayBeeps = 1){
	SoundBeep, 750, 50
	SoundBeep, 750, 50
	SoundBeep, 1000, 100
	}

If (CommandVar = "PlayPreviousClip"){
	PlayClip()
	}

If (CommandVar = "PlayNextClip"){
	PlayClip()
	}

If (CommandVar = "PlayCurrentClip"){
	PlayClip()
	}

if (DisplayText = 1){
	#CommentFlag //send {APPSKEY}r
	sleep, 500
	#CommentFlag //send {CTRL DOWN}{TAB}{TAB}{CTRLUP}
	Gui, Destroy
	}

Exit

ResetScript(){
	#CommentFlag // MsgBox Script Reset
	SoundBeep, 750, 50
	FileDelete, %ScriptPath%\ClipSeriesPlayerVar.TXT
	FileAppend, 1`n, *%ScriptPath%\ClipSeriesPlayerVar.TXT
	}

WriteScript(){
	#CommentFlag // ComObjCreate("SAPI.SpVoice").Speak(ScriptCount)
	#CommentFlag // ComObjCreate("SAPI.SpVoice").Speak("Writing Variable")
	#CommentFlag // 
	FileDelete, %ScriptPath%\ClipSeriesPlayerVar.TXT
	sleep, 500
	FileAppend, %ScriptCount%`n, *%ScriptPath%\ClipSeriesPlayerVar.TXT
	}

PlayClip(){
	if (ScriptCount > 10){
		ScriptNumber := ScriptCount
		} else {		
		ScriptNumber := "0" + ScriptCount
		}
	#CommentFlag //SoundVar := SoundPath . "\Clip_" . ScriptNumber . ".wav"
	SoundVar := SoundPath . "\Clip_" . ScriptNumber . ".wav"
	if (UseVLC = 1){
		Run, "C:\Program Files\VideoLAN\VLC\vlc.exe" "%SoundVar%"
		}
	if (UseVLC = 0){
		#Persistent
		SoundPlay, %SoundVar%, Wait
		}
	Return
	}

ReadScriptCount(){
	FileReadLine, ScriptCount, %ScriptPath%\ClipSeriesPlayerVar.TXT, 1
}